"""Contains some useful constants."""


MINUTE_SECONDS = 60
"""Number of seconds in minute."""

HOUR_SECONDS = 60 * MINUTE_SECONDS
"""Number of seconds in hour."""

DAY_SECONDS = 24 * HOUR_SECONDS
"""Number of seconds in day."""

WEEK_SECONDS = 7 * DAY_SECONDS
"""Number of seconds in week."""

MONTH_SECONDS = 4 * WEEK_SECONDS
"""Number of seconds in month."""


KILOBYTE = 1024
"""Number of bytes in kilobyte."""

MEGABYTE = 1024 * KILOBYTE
"""Number of bytes in megabyte."""

GIGABYTE = 1024 * MEGABYTE
"""Number of bytes in gigabyte."""

TERABYTE = 1024 * GIGABYTE
"""Number of bytes in terabyte."""
